/*
 * Demo Android application for Tellu Smart Platform REST API
 * library.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 */
package no.tellu.findit.client.android.demo;

import no.tellu.findit.client.api.AsyncService;
import no.tellu.findit.client.api.AsyncServiceImpl;
import android.app.Activity;
import android.os.Bundle;
import android.util.Log;
import android.widget.TextView;

/**
 * Demo/test of Tellu Smart Platform REST API library.
 * It logs in to a SmartTracker service, and performs
 * a number of API transactions, showing a log in the
 * user interface.
 * <p>
 * IMPORTANT NOTES ON USE:</br>
 * Server address and user name and password is specified
 * with constants at the start of this class. A valid
 * user name and password must be provided to run the code.
 * The API transactions will be performed in whatever
 * customer account the authenticated user is linked to.
 * A test Asset will be inserted, modified and deleted
 * (the user must have the necessary permissions).
 * 
 * @author Lars Thomas Boye, Tellu AS
 */
public class DemoActivity extends Activity {
	// Server instance to target
	public static final String API_URL = "https://www.smarttracker.no/web";
	
	// URL of edge for posting observations
	public static final String EDGE_URL = "http://thijs.tellu.c.bitbit.net:9160/observation";
	
	// User name for authentication - must be specified
	public static final String USERNAME = "user";
	
	// Password for authentication - must be specified
	public static final String PASSWORD = "1234";
	
	AsyncService apiService;
	TextView status;
	Transactions transactions = null;
	

	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.demo_activity);
		status = (TextView) findViewById(R.id.status);
		
		apiService = new AsyncServiceImpl(API_URL);
	}
	
	@Override
    protected void onStart() {
        super.onStart();
        if (transactions == null) {
        	//Not logged in, start demo
        	status.append("Log in as " + USERNAME + "\n");
        	AsyncService.AccountCallback callback = new AsyncService.AccountCallback() {
        		@Override
				public void onAccountOK(long customerId, String customer) {
        			status.append(".Login successful, account: " + customer + "\n");
        			transactions = new Transactions(apiService, status);
        			transactions.doDemoTransactions();
				}
        		
				@Override
				public void onAccountError(int code, String message, Exception e) {
					status.append(".Login failed with code " + code + "\n");
					status.append(".Error: " + message + "\n");
					Log.e(Transactions.LOG_TAG, "Login failed", e);
				}
        	};
        	
        	apiService.initiate(USERNAME, PASSWORD, callback);
        	//Either onAccountOK or onAccountError will be called
        }
	}
	
	
	@Override
    protected void onStop() {
        super.onStop();
        // The activity is no longer visible (it is now "stopped")
    }
	
	protected void onDestroy() {
		apiService.abortTransaction();
		transactions = null;
		super.onDestroy();
	}
}
